package org.jboss.as.integration.hornetq.deployers;

import org.hornetq.jms.server.JMSServerConfigParser;
import org.hornetq.jms.server.config.JMSConfiguration;
import org.hornetq.jms.server.impl.JMSServerConfigParserImpl;
import org.jboss.deployers.vfs.spi.deployer.AbstractVFSParsingDeployer;
import org.jboss.deployers.vfs.spi.structure.VFSDeploymentUnit;
import org.jboss.logging.Logger;
import org.jboss.vfs.VirtualFile;

import java.io.InputStream;


/**
 * This Deployer will take a hornetq-jms.xml parse the JMSConfiguration and
 * attach the JMSConfiguration output into the deployment unit. Another deployer
 * that takes JMSConfiguration as an input will then take over and install the
 * queues at the proper places.
 * 
 * This is done through the VFS Deployment Framework. Othe projects may choose to deploy a HornetQ JMSConfiguration directly.
 * 
 * @see HornetQJMSRealDeployer
 * 
 * @author <mailto:clebert.suconic@jboss.org">Clebert Suconic</a>
 * 
 */
public class HornetQJMSParserDeployer extends AbstractVFSParsingDeployer<JMSConfiguration>
{

    private static final Logger log = Logger.getLogger(HornetQJMSParserDeployer.class);

    public static final String FILENAME = "hornetq-jms.xml";

    private final JMSServerConfigParser jmsConfigParser;

    public HornetQJMSParserDeployer()
    {
        super(JMSConfiguration.class);

        this.jmsConfigParser = new JMSServerConfigParserImpl();
        
        setSuffix(FILENAME);
    }
    
    @Override
    protected JMSConfiguration parse(VFSDeploymentUnit unit, VirtualFile file, JMSConfiguration root) throws Exception
    {

        InputStream deploymentStream = null;

        try
        {
            deploymentStream = file.openStream();
            JMSConfiguration config = jmsConfigParser.parseConfiguration(deploymentStream);
            if (log.isTraceEnabled())
            {
               log.trace("JMS config parser parsed config = " + config);
            }
            return config;
        } finally
        {
            try
            {
                deploymentStream.close();
            } catch (Exception ignored)
            {
            }
        }
    }
    
}
